@@ -19,20 +19,17 @@ import _locale
 
 #return pandas dataframe
 
-#see parameters available for date_preset here https://developers.facebook.com/docs/marketing-api/insights/parameters/
+#See here for documentation https://developers.facebook.com/docs/marketing-api/insights/parameters/ 
 
 
 
 """
-MANDATORY INPUT: my_app_id, my_app_secret, my_access_token
+
+
+MANDATORY INPUT: my_app_id, my_app_secret, my_access_token, start_date, end_date,
 
 OPTIONAL:
 
-- date_preset: report days range.  
-               Optional, by default "last_7d".
-               See https://developers.facebook.com/docs/marketing-api/insights/parameters/ for date_preset available.
-
-
 - account_name: dictionary with name and id. 
                 Optional, by default it gets 'Humable','Linkers','WinWay', 'Miss Tariffa Agency','Numbers', 'We are Fiber', 'Miss Tariffa'
 
@@ -40,10 +37,10 @@ OPTIONAL:
 
 
 
-def get_fb_ads(my_app_id, my_app_secret, my_access_token, 
+def get_fb_ads(my_app_id, my_app_secret, my_access_token, start_date, end_date,
                
                #optional input below
-               date_preset = "last_7d",
+               
                account_name = {'Numbers' : 'act_113103090066338',
                 'Linkers' : 'act_203938767415072',
                 'WinWay' : 'act_2591302164494270',
@@ -54,7 +51,6 @@ def get_fb_ads(my_app_id, my_app_secret, my_access_token,
                }
               ):
     
-    print("date_preset is '{}'".format(date_preset))
     
     _locale._getdefaultlocale = (lambda *args: ['en_US', 'UTF-8'])
 
@@ -76,7 +72,7 @@ def get_fb_ads(my_app_id, my_app_secret, my_access_token,
     accounts = list(me.get_ad_accounts())
 
     params = {
-        'date_preset': date_preset,
+        "time_range" : {"since": start_date, "until": end_date},
         'fields': [
                     AdsInsights.Field.account_id,
                     AdsInsights.Field.account_name,
