@@ -84,7 +84,7 @@ def get_google_ads(start_date, end_date,
                               )
                           .From('CAMPAIGN_PERFORMANCE_REPORT')
                         #   .Where('CampaignStatus').In('ENABLED')
-                          .During(end_date+ ','+start_date) 
+                          .During(start_date+ ','+end_date) 
                           .Build())
 
         report_downloader.DownloadReportWithAwql(report_query, 'CSV', output, skip_report_header=True,
